==> DateTime-Locale-1.21.tar.gz: DateTime-Locale-1.21/share/zh-Hans-MO.pl <==
{
  am_pm_abbreviated => [
    "\N{U+4e0a}\N{U+5348}",
    "\N{U+4e0b}\N{U+5348}",
  ],
  available_formats => {
    Bh => "Bh\N{U+65f6}",
    Bhm => "Bh:mm",
    Bhms => "Bh:mm:ss",
    E => "ccc",
    EBhm => "EBh:mm",
    EBhms => "EBh:mm:ss",
    EHm => "EHH:mm",
    EHms => "EHH:mm:ss",
    Ed => "d\N{U+65e5}E",
    Ehm => "Eah:mm",
    Ehms => "Eah:mm:ss",
    Gy => "Gy\N{U+5e74}",
    GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
    GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    H => "H\N{U+65f6}",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "v HH:mm:ss",
    Hmv => "v HH:mm",
    M => "M\N{U+6708}",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "M\N{U+6708}d\N{U+65e5}E",
    "MMMMW-count-other" => "MMM\N{U+7b2c}W\N{U+5468}",
    MMMMd => "M\N{U+6708}d\N{U+65e5}",
    MMMMdd => "M\N{U+6708}d\N{U+65e5}",
    MMMd => "M\N{U+6708}d\N{U+65e5}",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d\N{U+65e5}",
    h => "ah\N{U+65f6}",
    hm => "ah:mm",
    hms => "ah:mm:ss",
    hmsv => "v ah:mm:ss",
    hmv => "v ah:mm",
    ms => "mm:ss",
    y => "y\N{U+5e74}",
    yM => "y\N{U+5e74}M\N{U+6708}",
    yMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}\N{U+ff0c}E",
    yMM => "y\N{U+5e74}M\N{U+6708}",
    yMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    yMMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yQQQ => "y\N{U+5e74}\N{U+7b2c}Q\N{U+5b63}\N{U+5ea6}",
    yQQQQ => "y\N{U+5e74}\N{U+7b2c}Q\N{U+5b63}\N{U+5ea6}",
    "yw-count-other" => "Y\N{U+5e74}\N{U+7b2c}w\N{U+5468}",
  },
  code => "zh-Hans-MO",
  date_format_full => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}EEEE",
  date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_format_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_format_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_stand_alone_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_stand_alone_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  era_abbreviated => [
    "\N{U+516c}\N{U+5143}\N{U+524d}",
    "\N{U+516c}\N{U+5143}",
  ],
  era_narrow => [
    "\N{U+516c}\N{U+5143}\N{U+524d}",
    "\N{U+516c}\N{U+5143}",
  ],
  era_wide => [
    "\N{U+516c}\N{U+5143}\N{U+524d}",
    "\N{U+516c}\N{U+5143}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Chinese",
  month_format_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  name => "Chinese Macau SAR China Simplified",
  native_language => "\N{U+4e2d}\N{U+6587}",
  native_name => "\N{U+4e2d}\N{U+6587} \N{U+4e2d}\N{U+56fd}\N{U+6fb3}\N{U+95e8}\N{U+7279}\N{U+522b}\N{U+884c}\N{U+653f}\N{U+533a} \N{U+7b80}\N{U+4f53}",
  native_script => "\N{U+7b80}\N{U+4f53}",
  native_territory => "\N{U+4e2d}\N{U+56fd}\N{U+6fb3}\N{U+95e8}\N{U+7279}\N{U+522b}\N{U+884c}\N{U+653f}\N{U+533a}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1\N{U+5b63}\N{U+5ea6}",
    "2\N{U+5b63}\N{U+5ea6}",
    "3\N{U+5b63}\N{U+5ea6}",
    "4\N{U+5b63}\N{U+5ea6}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+7b2c}\N{U+4e00}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e8c}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e09}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+56db}\N{U+5b63}\N{U+5ea6}",
  ],
  quarter_stand_alone_abbreviated => [
    "1\N{U+5b63}\N{U+5ea6}",
    "2\N{U+5b63}\N{U+5ea6}",
    "3\N{U+5b63}\N{U+5ea6}",
    "4\N{U+5b63}\N{U+5ea6}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+7b2c}\N{U+4e00}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e8c}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e09}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+56db}\N{U+5b63}\N{U+5ea6}",
  ],
  script => "Simplified",
  territory => "Macau SAR China",
  time_format_full => "zzzz ah:mm:ss",
  time_format_long => "z ah:mm:ss",
  time_format_medium => "ah:mm:ss",
  time_format_short => "ah:mm",
  variant => undef,
  version => 33,
}

==> DateTime-Locale-1.28.tar.gz: DateTime-Locale-1.28/share/zh-Hans-MO.pl <==
{
  am_pm_abbreviated => [
    "\N{U+4e0a}\N{U+5348}",
    "\N{U+4e0b}\N{U+5348}",
  ],
  available_formats => {
    Bh => "Bh\N{U+65f6}",
    Bhm => "Bh:mm",
    Bhms => "Bh:mm:ss",
    E => "ccc",
    EBhm => "EBh:mm",
    EBhms => "EBh:mm:ss",
    EHm => "EHH:mm",
    EHms => "EHH:mm:ss",
    Ed => "d\N{U+65e5}E",
    Ehm => "Eah:mm",
    Ehms => "Eah:mm:ss",
    Gy => "Gy\N{U+5e74}",
    GyMMM => "Gy\N{U+5e74}M\N{U+6708}",
    GyMMMEd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    GyMMMd => "Gy\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    H => "H\N{U+65f6}",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "v HH:mm:ss",
    Hmv => "v HH:mm",
    M => "M\N{U+6708}",
    MEd => "E, d/M",
    MMM => "LLL",
    MMMEd => "M\N{U+6708}d\N{U+65e5}E",
    "MMMMW-count-other" => "MMMM\N{U+7b2c}W\N{U+5468}",
    MMMMd => "M\N{U+6708}d\N{U+65e5}",
    MMMMdd => "M\N{U+6708}d\N{U+65e5}",
    MMMd => "M\N{U+6708}d\N{U+65e5}",
    MMdd => "dd/MM",
    Md => "d/M",
    d => "d\N{U+65e5}",
    h => "ah\N{U+65f6}",
    hm => "ah:mm",
    hms => "ah:mm:ss",
    hmsv => "v ah:mm:ss",
    hmv => "v ah:mm",
    ms => "mm:ss",
    y => "y\N{U+5e74}",
    yM => "y\N{U+5e74}M\N{U+6708}",
    yMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}\N{U+ff0c}E",
    yMM => "y\N{U+5e74}M\N{U+6708}",
    yMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMEd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}E",
    yMMMM => "y\N{U+5e74}M\N{U+6708}",
    yMMMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yMd => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
    yQQQ => "y\N{U+5e74}\N{U+7b2c}Q\N{U+5b63}\N{U+5ea6}",
    yQQQQ => "y\N{U+5e74}\N{U+7b2c}Q\N{U+5b63}\N{U+5ea6}",
    "yw-count-other" => "Y\N{U+5e74}\N{U+7b2c}w\N{U+5468}",
  },
  code => "zh-Hans-MO",
  date_format_full => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}EEEE",
  date_format_long => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_medium => "y\N{U+5e74}M\N{U+6708}d\N{U+65e5}",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_format_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_format_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+5468}\N{U+4e00}",
    "\N{U+5468}\N{U+4e8c}",
    "\N{U+5468}\N{U+4e09}",
    "\N{U+5468}\N{U+56db}",
    "\N{U+5468}\N{U+4e94}",
    "\N{U+5468}\N{U+516d}",
    "\N{U+5468}\N{U+65e5}",
  ],
  day_stand_alone_narrow => [
    "\N{U+4e00}",
    "\N{U+4e8c}",
    "\N{U+4e09}",
    "\N{U+56db}",
    "\N{U+4e94}",
    "\N{U+516d}",
    "\N{U+65e5}",
  ],
  day_stand_alone_wide => [
    "\N{U+661f}\N{U+671f}\N{U+4e00}",
    "\N{U+661f}\N{U+671f}\N{U+4e8c}",
    "\N{U+661f}\N{U+671f}\N{U+4e09}",
    "\N{U+661f}\N{U+671f}\N{U+56db}",
    "\N{U+661f}\N{U+671f}\N{U+4e94}",
    "\N{U+661f}\N{U+671f}\N{U+516d}",
    "\N{U+661f}\N{U+671f}\N{U+65e5}",
  ],
  era_abbreviated => [
    "\N{U+516c}\N{U+5143}\N{U+524d}",
    "\N{U+516c}\N{U+5143}",
  ],
  era_narrow => [
    "\N{U+516c}\N{U+5143}\N{U+524d}",
    "\N{U+516c}\N{U+5143}",
  ],
  era_wide => [
    "\N{U+516c}\N{U+5143}\N{U+524d}",
    "\N{U+516c}\N{U+5143}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Chinese",
  month_format_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_format_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_format_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  month_stand_alone_abbreviated => [
    "1\N{U+6708}",
    "2\N{U+6708}",
    "3\N{U+6708}",
    "4\N{U+6708}",
    "5\N{U+6708}",
    "6\N{U+6708}",
    "7\N{U+6708}",
    "8\N{U+6708}",
    "9\N{U+6708}",
    "10\N{U+6708}",
    "11\N{U+6708}",
    "12\N{U+6708}",
  ],
  month_stand_alone_narrow => [
    1,
    2,
    3,
    4,
    5,
    6,
    7,
    8,
    9,
    10,
    11,
    12,
  ],
  month_stand_alone_wide => [
    "\N{U+4e00}\N{U+6708}",
    "\N{U+4e8c}\N{U+6708}",
    "\N{U+4e09}\N{U+6708}",
    "\N{U+56db}\N{U+6708}",
    "\N{U+4e94}\N{U+6708}",
    "\N{U+516d}\N{U+6708}",
    "\N{U+4e03}\N{U+6708}",
    "\N{U+516b}\N{U+6708}",
    "\N{U+4e5d}\N{U+6708}",
    "\N{U+5341}\N{U+6708}",
    "\N{U+5341}\N{U+4e00}\N{U+6708}",
    "\N{U+5341}\N{U+4e8c}\N{U+6708}",
  ],
  name => "Chinese Macao SAR China Simplified",
  native_language => "\N{U+4e2d}\N{U+6587}",
  native_name => "\N{U+4e2d}\N{U+6587} \N{U+4e2d}\N{U+56fd}\N{U+6fb3}\N{U+95e8}\N{U+7279}\N{U+522b}\N{U+884c}\N{U+653f}\N{U+533a} \N{U+7b80}\N{U+4f53}",
  native_script => "\N{U+7b80}\N{U+4f53}",
  native_territory => "\N{U+4e2d}\N{U+56fd}\N{U+6fb3}\N{U+95e8}\N{U+7279}\N{U+522b}\N{U+884c}\N{U+653f}\N{U+533a}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1\N{U+5b63}\N{U+5ea6}",
    "2\N{U+5b63}\N{U+5ea6}",
    "3\N{U+5b63}\N{U+5ea6}",
    "4\N{U+5b63}\N{U+5ea6}",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+7b2c}\N{U+4e00}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e8c}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e09}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+56db}\N{U+5b63}\N{U+5ea6}",
  ],
  quarter_stand_alone_abbreviated => [
    "1\N{U+5b63}\N{U+5ea6}",
    "2\N{U+5b63}\N{U+5ea6}",
    "3\N{U+5b63}\N{U+5ea6}",
    "4\N{U+5b63}\N{U+5ea6}",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+7b2c}\N{U+4e00}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e8c}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+4e09}\N{U+5b63}\N{U+5ea6}",
    "\N{U+7b2c}\N{U+56db}\N{U+5b63}\N{U+5ea6}",
  ],
  script => "Simplified",
  territory => "Macao SAR China",
  time_format_full => "zzzz ah:mm:ss",
  time_format_long => "z ah:mm:ss",
  time_format_medium => "ah:mm:ss",
  time_format_short => "ah:mm",
  variant => undef,
  version => 37,
}
